@@ -349,8 +349,8 @@ class PageCompiler(BasePlugin):
 
         if isinstance(extractor, MetadataExtractor):
             return extractor.split_metadata_from_text(data)
-        else:
-            return data, data
+        # Ouch!
+        return data, data
 
     def get_compiler_extensions(self) -> list:
         """Activate all the compiler extension plugins for a given compiler and return them."""
@@ -481,7 +481,7 @@ class ShortcodePlugin(BasePlugin):
         """Set Nikola site."""
         self.site = site
         site.register_shortcode(self.name, self.handler)
-        return super(ShortcodePlugin, self).set_site(site)
+        return super().set_site(site)
 
 
 class Importer(Command):
