@@ -79,7 +79,7 @@ class CommandAuto(Command):
             'long': 'port',
             'default': 8000,
             'type': int,
-            'help': 'Port number (default: 8000)',
+            'help': 'Port number)',
         },
         {
             'name': 'address',
@@ -87,7 +87,7 @@ class CommandAuto(Command):
             'long': 'address',
             'type': str,
             'default': '127.0.0.1',
-            'help': 'Address to bind (default: 127.0.0.1 -- localhost)',
+            'help': 'Address to bind',
         },
         {
             'name': 'browser',
@@ -248,8 +248,11 @@ class CommandAuto(Command):
         self.logger.info("Serving on {0} ...".format(server_url))
 
         if browser:
+            # Some browsers fail to load 0.0.0.0 (Issue #2755)
+            if host == '0.0.0.0':
+                server_url = "http://127.0.0.1:{0}/".format(port)
             self.logger.info("Opening {0} in the default web browser...".format(server_url))
-            webbrowser.open('http://{0}:{1}'.format(host, port))
+            webbrowser.open(server_url)
 
         # Run the event loop forever and handle shutdowns.
         try:
