@@ -51,11 +51,12 @@ class RenderTaxonomies(Task):
         context = copy(context)
         context["kind"] = "{}_index".format(taxonomy.classification_name)
         sorted_links = []
-        sorted_links_all = []
         for other_lang in sorted(self.site.config['TRANSLATIONS'].keys()):
-            sorted_links_all.append((other_lang, None, None))
             if other_lang != lang:
                 sorted_links.append((other_lang, None, None))
+        # Put the current language in front, so that it appears first in links
+        # (Issue #3248)
+        sorted_links_all = [(lang, None, None)] + sorted_links
         context['has_other_languages'] = True
         context['other_languages'] = sorted_links
         context['all_languages'] = sorted_links_all
