@@ -52,7 +52,6 @@ from .utils import (
     LocaleBorg,
     slugify,
     to_datetime,
-    unicode_str,
     demote_headers,
     get_translation_candidate,
     map_metadata
@@ -72,6 +71,18 @@ TEASER_REGEXP = re.compile(r'<!--\s*(TEASER_END|END_TEASER)(:(.+))?\s*-->', re.I
 class Post(object):
     """Represent a blog post or site page."""
 
+    _prev_post = None
+    _next_post = None
+    is_draft = False
+    is_private = False
+    _is_two_file = None
+    _reading_time = None
+    _remaining_reading_time = None
+    _paragraph_count = None
+    _remaining_paragraph_count = None
+    post_status = 'published'
+    has_oldstyle_metadata_tags = False
+
     def __init__(
         self,
         source_path,
@@ -93,47 +104,15 @@ class Post(object):
         destination_base must be None or a TranslatableSetting instance. If
         specified, it will be prepended to the destination path.
         """
-        self.config = config
+        self._load_config(config)
+        self._set_paths(source_path)
+
         self.compiler = compiler
-        self.compiler_contexts = {}
+        self.is_post = use_in_feeds
+        self.messages = messages
+        self._template_name = template_name
         self.compile_html = self.compiler.compile
         self.demote_headers = self.compiler.demote_headers and self.config['DEMOTE_HEADERS']
-        tzinfo = self.config['__tzinfo__']
-        if self.config['FUTURE_IS_NOW']:
-            self.current_time = None
-        else:
-            self.current_time = current_time(tzinfo)
-        self.translated_to = set([])
-        self._prev_post = None
-        self._next_post = None
-        self.base_url = self.config['BASE_URL']
-        self.is_draft = False
-        self.is_private = False
-        self.strip_indexes = self.config['STRIP_INDEXES']
-        self.index_file = self.config['INDEX_FILE']
-        self.pretty_urls = self.config['PRETTY_URLS']
-        self.source_path = source_path  # posts/blah.txt
-        self.post_name = os.path.splitext(source_path)[0]  # posts/blah
-        _relpath = os.path.relpath(self.post_name)
-        if _relpath != self.post_name:
-            self.post_name = _relpath.replace('..' + os.sep, '_..' + os.sep)
-        # cache[\/]posts[\/]blah.html
-        self.base_path = os.path.join(self.config['CACHE_FOLDER'], self.post_name + ".html")
-        # cache/posts/blah.html
-        self._base_path = self.base_path.replace('\\', '/')
-        self.metadata_path = self.post_name + ".meta"  # posts/blah.meta
-        self.folder_relative = destination
-        self.folder_base = destination_base
-        self.default_lang = self.config['DEFAULT_LANG']
-        self.translations = self.config['TRANSLATIONS']
-        self.messages = messages
-        self.skip_untranslated = not self.config['SHOW_UNTRANSLATED_POSTS']
-        self._template_name = template_name
-        self.is_two_file = True
-        self._reading_time = None
-        self._remaining_reading_time = None
-        self._paragraph_count = None
-        self._remaining_paragraph_count = None
         self._dependency_file_fragment = defaultdict(list)
         self._dependency_file_page = defaultdict(list)
         self._dependency_uptodate_fragment = defaultdict(list)
@@ -144,119 +123,65 @@ class Post(object):
         else:
             self.metadata_extractors_by = metadata_extractors_by
 
-        # Load internationalized metadata
-        for lang in self.translations:
-            if os.path.isfile(get_translation_candidate(self.config, self.source_path, lang)):
-                self.translated_to.add(lang)
+        self._set_translated_to()
+        self._set_folders(destination, destination_base)
 
+        # Load default metadata
         default_metadata, default_used_extractor = get_meta(self, lang=None)
-
         self.meta = Functionary(lambda: None, self.default_lang)
         self.used_extractor = Functionary(lambda: None, self.default_lang)
         self.meta[self.default_lang] = default_metadata
         self.used_extractor[self.default_lang] = default_used_extractor
 
-        # Compose paths
-        if self.folder_base is not None:
-            # Use translatable destination folders
-            self.folders = {}
-            for lang in self.config['TRANSLATIONS'].keys():
-                if os.path.isabs(self.folder_base(lang)):  # Issue 2982
-                    self.folder_base[lang] = os.path.relpath(self.folder_base(lang), '/')
-                self.folders[lang] = os.path.normpath(os.path.join(self.folder_base(lang), self.folder_relative))
-        else:
-            # Old behavior (non-translatable destination path, normalized by scanner)
-            self.folders = {lang: self.folder_relative for lang in self.config['TRANSLATIONS'].keys()}
-        self.folder = self.folders[self.default_lang]
+        self._set_date(default_metadata)
 
-        if 'date' not in default_metadata and not use_in_feeds:
-            # For pages we don't *really* need a date
-            if self.config['__invariant__']:
-                default_metadata['date'] = datetime.datetime(2013, 12, 31, 23, 59, 59, tzinfo=tzinfo)
-            else:
-                default_metadata['date'] = datetime.datetime.utcfromtimestamp(
-                    os.stat(self.source_path).st_ctime).replace(tzinfo=dateutil.tz.tzutc()).astimezone(tzinfo)
-
-        # If time zone is set, build localized datetime.
-        try:
-            self.date = to_datetime(self.meta[self.default_lang]['date'], tzinfo)
-        except ValueError:
-            if not self.meta[self.default_lang]['date']:
-                msg = 'Missing date in file {}'.format(source_path)
-            else:
-                msg = "Invalid date '{0}' in file {1}".format(self.meta[self.default_lang]['date'], source_path)
-            LOGGER.error(msg)
-            raise ValueError(msg)
-
-        if 'updated' not in default_metadata:
-            default_metadata['updated'] = default_metadata.get('date', None)
-
-        self.updated = to_datetime(default_metadata['updated'], tzinfo)
-
-        if 'title' not in default_metadata or 'slug' not in default_metadata \
-                or 'date' not in default_metadata:
-            raise ValueError("You must set a title (found '{0}'), a slug (found '{1}') and a date (found '{2}')! "
-                             "[in file {3}]".format(default_metadata.get('title', None),
+        # These are the required metadata fields
+        if 'title' not in default_metadata or 'slug' not in default_metadata:
+            raise ValueError("You must set a title (found '{0}') and a slug (found '{1}')! "
+                             "[in file {2}]".format(default_metadata.get('title', None),
                                                     default_metadata.get('slug', None),
-                                                    default_metadata.get('date', None),
                                                     source_path))
 
         if 'type' not in default_metadata:
-            # default value is 'text'
             default_metadata['type'] = 'text'
 
-        for lang in self.translations:
-            if lang != self.default_lang:
-                meta = defaultdict(lambda: '')
-                meta.update(default_metadata)
-                _meta, _extractors = get_meta(self, lang)
-                meta.update(_meta)
-                self.meta[lang] = meta
-                self.used_extractor[lang] = _extractors
-
-        if not self.is_translation_available(self.default_lang):
-            # Special case! (Issue #373)
-            # Fill default_metadata with stuff from the other languages
-            for lang in sorted(self.translated_to):
-                default_metadata.update(self.meta[lang])
-
-        # Load data field from metadata
-        self.data = Functionary(lambda: None, self.default_lang)
-        for lang in self.translations:
-            if self.meta[lang].get('data') is not None:
-                self.data[lang] = utils.load_data(self.meta[lang]['data'])
-
-        for lang, meta in self.meta.items():
-            # Migrate section to category
-            # TODO: remove in v9
-            if 'section' in meta:
-                if 'category' in meta:
-                    LOGGER.warning("Post {0} has both 'category' and 'section' metadata. Section will be ignored.".format(source_path))
-                else:
-                    meta['category'] = meta['section']
-                    LOGGER.info("Post {0} uses 'section' metadata, setting its value to 'category'".format(source_path))
-
-            # Handle CATEGORY_DESTPATH_AS_DEFAULT
-            if 'category' not in meta and self.config['CATEGORY_DESTPATH_AS_DEFAULT']:
-                self.category_from_destpath = True
-                if self.config['CATEGORY_DESTPATH_TRIM_PREFIX'] and self.folder_relative != '.':
-                    category = self.folder_relative
-                else:
-                    category = self.folders[lang]
-                category = category.replace(os.sep, '/')
-                if self.config['CATEGORY_DESTPATH_FIRST_DIRECTORY_ONLY']:
-                    category = category.split('/')[0]
-                meta['category'] = self.config['CATEGORY_DESTPATH_NAMES'](lang).get(category, category)
-            else:
-                self.category_from_destpath = False
+        self._load_translated_metadata(default_metadata)
+        self._load_data()
+        self.__migrate_section_to_category()
+        self._set_tags()
 
         self.publish_later = False if self.current_time is None else self.date >= self.current_time
 
-        self.is_draft = False
-        self.is_private = False
-        self.post_status = 'published'
+        # While draft comes from the tags, it's not really a tag
+        self.use_in_feeds = self.is_post and not self.is_draft and not self.is_private and not self.publish_later
+
+        # Allow overriding URL_TYPE via meta
+        # The check is done here so meta dicts won’t change inside of
+        # generic_post_renderer
+        self.url_type = self.meta('url_type') or None
+        # Register potential extra dependencies
+        self.compiler.register_extra_dependencies(self)
+
+    def _load_config(self, config):
+        """Set members to configured values."""
+        self.config = config
+        if self.config['FUTURE_IS_NOW']:
+            self.current_time = None
+        else:
+            self.current_time = current_time(self.config['__tzinfo__'])
+        self.base_url = self.config['BASE_URL']
+        self.strip_indexes = self.config['STRIP_INDEXES']
+        self.index_file = self.config['INDEX_FILE']
+        self.pretty_urls = self.config['PRETTY_URLS']
+        self.default_lang = self.config['DEFAULT_LANG']
+        self.translations = self.config['TRANSLATIONS']
+        self.skip_untranslated = not self.config['SHOW_UNTRANSLATED_POSTS']
+        self._default_preview_image = self.config['DEFAULT_PREVIEW_IMAGE']
+        self.types_to_hide_title = self.config['TYPES_TO_HIDE_TITLE']
+
+    def _set_tags(self):
+        """Set post tags."""
         self._tags = {}
-        self.has_oldstyle_metadata_tags = False
         for lang in self.translated_to:
             if isinstance(self.meta[lang]['tags'], (list, tuple, set)):
                 _tag_list = self.meta[lang]['tags']
@@ -318,28 +243,178 @@ class Post(object):
                 if 'mathjax' in self._tags[lang]:
                     self.has_oldstyle_metadata_tags = True
 
-        # While draft comes from the tags, it's not really a tag
-        self.is_post = use_in_feeds
-        self.use_in_feeds = self.is_post and not self.is_draft and not self.is_private and not self.publish_later
+    def _set_paths(self, source_path):
+        """Set the various paths and the post_name.
 
-        # Allow overriding URL_TYPE via meta
-        # The check is done here so meta dicts won’t change inside of
-        # generic_post_rendere
-        self.url_type = self.meta('url_type') or None
-        # Register potential extra dependencies
-        self.compiler.register_extra_dependencies(self)
+        TODO: WTF is all this.
+        """
+        self.source_path = source_path  # posts/blah.txt
+        self.post_name = os.path.splitext(source_path)[0]  # posts/blah
+        _relpath = os.path.relpath(self.post_name)
+        if _relpath != self.post_name:
+            self.post_name = _relpath.replace('..' + os.sep, '_..' + os.sep)
+        # cache[\/]posts[\/]blah.html
+        self.base_path = os.path.join(self.config['CACHE_FOLDER'], self.post_name + ".html")
+        # cache/posts/blah.html
+        self._base_path = self.base_path.replace('\\', '/')
+        self.metadata_path = self.post_name + ".meta"  # posts/blah.meta
 
-    def _get_hyphenate(self):
+    def _set_translated_to(self):
+        """Find post's translations."""
+        self.translated_to = set([])
+        for lang in self.translations:
+            if os.path.isfile(get_translation_candidate(self.config, self.source_path, lang)):
+                self.translated_to.add(lang)
+
+        # If we don't have anything in translated_to, the file does not exist
+        if not self.translated_to and os.path.isfile(self.source_path):
+            raise Exception(("Could not find translations for {}, check your "
+                            "TRANSLATIONS_PATTERN").format(self.source_path))
+        elif not self.translated_to:
+            raise Exception(("Cannot use {} (not a file, perhaps a broken "
+                            "symbolic link?)").format(self.source_path))
+
+    def _set_folders(self, destination, destination_base):
+        """Compose destination paths."""
+        self.folder_relative = destination
+        self.folder_base = destination_base
+
+        if self.folder_base is not None:
+            # Use translatable destination folders
+            self.folders = {}
+            for lang in self.config['TRANSLATIONS']:
+                if os.path.isabs(self.folder_base(lang)):  # Issue 2982
+                    self.folder_base[lang] = os.path.relpath(self.folder_base(lang), '/')
+                self.folders[lang] = os.path.normpath(os.path.join(self.folder_base(lang), self.folder_relative))
+        else:
+            # Old behavior (non-translatable destination path, normalized by scanner)
+            self.folders = {lang: self.folder_relative for lang in self.config['TRANSLATIONS'].keys()}
+        self.folder = self.folders[self.default_lang]
+
+    def __migrate_section_to_category(self):
+        """TODO: remove in v9."""
+        for lang, meta in self.meta.items():
+            # Migrate section to category
+            # TODO: remove in v9
+            if 'section' in meta:
+                if 'category' in meta:
+                    LOGGER.warning("Post {0} has both 'category' and 'section' metadata. Section will be ignored.".format(self.source_path))
+                else:
+                    meta['category'] = meta['section']
+                    LOGGER.info("Post {0} uses 'section' metadata, setting its value to 'category'".format(self.source_path))
+
+            # Handle CATEGORY_DESTPATH_AS_DEFAULT
+            if 'category' not in meta and self.config['CATEGORY_DESTPATH_AS_DEFAULT']:
+                self.category_from_destpath = True
+                if self.config['CATEGORY_DESTPATH_TRIM_PREFIX'] and self.folder_relative != '.':
+                    category = self.folder_relative
+                else:
+                    category = self.folders[lang]
+                category = category.replace(os.sep, '/')
+                if self.config['CATEGORY_DESTPATH_FIRST_DIRECTORY_ONLY']:
+                    category = category.split('/')[0]
+                meta['category'] = self.config['CATEGORY_DESTPATH_NAMES'](lang).get(category, category)
+            else:
+                self.category_from_destpath = False
+
+    def _load_data(self):
+        """Load data field from metadata."""
+        self.data = Functionary(lambda: None, self.default_lang)
+        for lang in self.translations:
+            if self.meta[lang].get('data') is not None:
+                self.data[lang] = utils.load_data(self.meta[lang]['data'])
+
+    def _load_translated_metadata(self, default_metadata):
+        """Load metadata from all translation sources."""
+        for lang in self.translations:
+            if lang != self.default_lang:
+                meta = defaultdict(lambda: '')
+                meta.update(default_metadata)
+                _meta, _extractors = get_meta(self, lang)
+                meta.update(_meta)
+                self.meta[lang] = meta
+                self.used_extractor[lang] = _extractors
+
+        if not self.is_translation_available(self.default_lang):
+            # Special case! (Issue #373)
+            # Fill default_metadata with stuff from the other languages
+            for lang in sorted(self.translated_to):
+                default_metadata.update(self.meta[lang])
+
+    def _set_date(self, default_metadata):
+        """Set post date/updated based on metadata and configuration."""
+        if 'date' not in default_metadata and not self.is_post:
+            # For pages we don't *really* need a date
+            if self.config['__invariant__']:
+                default_metadata['date'] = datetime.datetime(2013, 12, 31, 23, 59, 59, tzinfo=self.config['__tzinfo__'])
+            else:
+                default_metadata['date'] = datetime.datetime.utcfromtimestamp(
+                    os.stat(self.source_path).st_ctime).replace(tzinfo=dateutil.tz.tzutc()).astimezone(self.config['__tzinfo__'])
+
+        # If time zone is set, build localized datetime.
+        try:
+            self.date = to_datetime(self.meta[self.default_lang]['date'], self.config['__tzinfo__'])
+        except ValueError:
+            if not self.meta[self.default_lang]['date']:
+                msg = 'Missing date in file {}'.format(self.source_path)
+            else:
+                msg = "Invalid date '{0}' in file {1}".format(self.meta[self.default_lang]['date'], self.source_path)
+            LOGGER.error(msg)
+            raise ValueError(msg)
+
+        if 'updated' not in default_metadata:
+            default_metadata['updated'] = default_metadata.get('date', None)
+
+        self.updated = to_datetime(default_metadata['updated'], self.config['__tzinfo__'])
+
+    @property
+    def hyphenate(self):
+        """Post is hyphenated."""
         return bool(self.config['HYPHENATE'] or self.meta('hyphenate'))
 
-    hyphenate = property(_get_hyphenate)
+    @property
+    def is_two_file(self):
+        """Post has a separate .meta file."""
+        if self._is_two_file is None:
+            return True
+        return self._is_two_file
+
+    @is_two_file.setter
+    def is_two_file(self, value):
+        """Set the is_two_file property, use with care.
+
+        Caution: this MAY REWRITE THE POST FILE.
+        Only should happen if you effectively *change* the value.
+
+        Arguments:
+            value {bool} -- Whether the post has a separate .meta file
+        """
+        # for lang in self.translated_to:
+
+        if self._is_two_file is None:
+            # Initial setting, this happens on post creation
+            self._is_two_file = value
+        elif value != self._is_two_file:
+            # Changing the value, this means you are transforming a 2-file
+            # into a 1-file or viceversa.
+            if value and not self.compiler.supports_metadata:
+                raise ValueError("Can't save metadata as 1-file using this compiler {}".format(self.compiler))
+            for lang in self.translated_to:
+                source = self.source(lang)
+                meta = self.meta(lang)
+                self._is_two_file = value
+                self.save(lang=lang, source=source, meta=meta)
+                if not value:  # Need to delete old meta file
+                    meta_path = get_translation_candidate(self.config, self.metadata_path, lang)
+                    if os.path.isfile(meta_path):
+                        os.unlink(meta_path)
 
     def __repr__(self):
         """Provide a representation of the post object."""
         # Calculate a hash that represents most data about the post
         m = hashlib.md5()
         # source_path modification date (to avoid reading it)
-        m.update(utils.unicode_str(os.stat(self.source_path).st_mtime).encode('utf-8'))
+        m.update(str(os.stat(self.source_path).st_mtime).encode('utf-8'))
         clean_meta = {}
         for k, v in self.meta.items():
             sub_meta = {}
@@ -347,7 +422,7 @@ class Post(object):
             for kk, vv in v.items():
                 if vv:
                     sub_meta[kk] = vv
-        m.update(utils.unicode_str(json.dumps(clean_meta, cls=utils.CustomEncoder, sort_keys=True)).encode('utf-8'))
+        m.update(str(json.dumps(clean_meta, cls=utils.CustomEncoder, sort_keys=True)).encode('utf-8'))
         return '<Post: {0!r} {1}>'.format(self.source_path, m.hexdigest())
 
     def has_pretty_url(self, lang):
@@ -695,20 +770,90 @@ class Post(object):
         return get_translation_candidate(self.config, self.base_path, lang)
 
     def _translated_file_path(self, lang):
-        """Return path to the translation's file, or to the original."""
+        """Get path to a post's translation.
+
+        Returns path to the translation's file, or to as good a file as it can
+        plus "real" language of the text.
+        """
         if lang in self.translated_to:
             if lang == self.default_lang:
-                return self.base_path
+                return self.base_path, lang
             else:
-                return get_translation_candidate(self.config, self.base_path, lang)
+                return get_translation_candidate(self.config, self.base_path, lang), lang
         elif lang != self.default_lang:
-            return self.base_path
+            return self.base_path, self.default_lang
         else:
-            return get_translation_candidate(self.config, self.base_path, sorted(self.translated_to)[0])
+            real_lang = sorted(self.translated_to)[0]
+            return get_translation_candidate(self.config, self.base_path, real_lang), real_lang
+
+    def write_metadata(self, lang=None):
+        """Save the post's metadata.
+
+        Keep in mind that this will save either in the
+        post file or in a .meta file, depending on self.is_two_file.
+
+        metadata obtained from filenames or document contents will
+        be superseded by this, and becomes inaccessible.
+
+        Post contents will **not** be modified.
+
+        If you write to a language not in self.translated_to
+        an exception will be raised.
+
+        Remember to scan_posts(really=True) after you update metadata if
+        you want the rest of the system to know about the change.
+        """
+        if lang is None:
+            lang = nikola.utils.LocaleBorg().current_lang
+        if lang not in self.translated_to:
+            raise ValueError("Can't save post metadata to language [{}] it's not translated to.".format(lang))
+
+        source = self.source(lang)
+        source_path = self.translated_source_path(lang)
+        metadata = self.meta[lang]
+        self.compiler.create_post(source_path, content=source, onefile=not self.is_two_file, is_page=not self.is_post, **metadata)
+
+    def save(self, lang=None, source=None, meta=None):
+        """Write post source to disk.
+
+        Use this with utmost care, it may wipe out a post.
+
+        Keyword Arguments:
+            lang str -- Language for this source. If set to None,
+                use current language.
+            source str -- The source text for the post in the
+                language. If set to None, use current source for
+                this language.
+            meta dict -- Metadata for this language, if not set,
+                use current metadata for this language.
+        """
+        if lang is None:
+            lang = nikola.utils.LocaleBorg().current_lang
+        if source is None:
+            source = self.source(lang)
+        if meta is None:
+            metadata = self.meta[lang]
+        source_path = self.translated_source_path(lang)
+        metadata = self.meta[lang]
+        self.compiler.create_post(source_path, content=source, onefile=not self.is_two_file, is_page=not self.is_post, **metadata)
+
+    def source(self, lang=None):
+        """Read the post and return its source."""
+        if lang is None:
+            lang = nikola.utils.LocaleBorg().current_lang
+
+        source = self.translated_source_path(lang)
+        with open(source, encoding='utf-8') as inf:
+            data = inf.read()
+        if self.is_two_file:  # Metadata is not here
+            source_data = data
+        else:
+            source_data = self.compiler.split_metadata(data, self, lang)[1]
+        return source_data
 
     def text(self, lang=None, teaser_only=False, strip_html=False, show_read_more_link=True,
              feed_read_more_link=False, feed_links_append_query=None):
-        """Read the post file for that language and return its contents.
+        """Read the post file for that language and return its compiled contents.
 
         teaser_only=True breaks at the teaser marker and returns only the teaser.
         strip_html=True removes HTML tags
@@ -721,7 +866,7 @@ class Post(object):
         """
         if lang is None:
             lang = nikola.utils.LocaleBorg().current_lang
-        file_name = self._translated_file_path(lang)
+        file_name, real_lang = self._translated_file_path(lang)
 
         # Yes, we compile it and screw it.
         # This may be controversial, but the user (or someone) is asking for the post text
@@ -746,7 +891,7 @@ class Post(object):
         document.make_links_absolute(base_url)
 
         if self.hyphenate:
-            hyphenate(document, lang)
+            hyphenate(document, real_lang)
 
         try:
             data = lxml.html.tostring(document.body, encoding='unicode')
@@ -829,7 +974,7 @@ class Post(object):
         if self._paragraph_count is None:
             # duplicated with Post.text()
             lang = nikola.utils.LocaleBorg().current_lang
-            file_name = self._translated_file_path(lang)
+            file_name, _ = self._translated_file_path(lang)
             with io.open(file_name, "r", encoding="utf8") as post_file:
                 data = post_file.read().strip()
             try:
@@ -924,9 +1069,8 @@ class Post(object):
             lang = nikola.utils.LocaleBorg().current_lang
 
         image_path = self.meta[lang]['previewimage']
-
         if not image_path:
-            return None
+            return self._default_preview_image
 
         # This is further parsed by the template, because we don’t have access
         # to the URL replacer here.  (Issue #1473)
@@ -946,6 +1090,15 @@ class Post(object):
         else:
             return ext
 
+    def should_hide_title(self):
+        """Return True if this post's title should be hidden. Use in templates to manage posts without titles."""
+        return self.title().strip() in ('NO TITLE', '') or self.meta('hidetitle') or \
+            self.meta('type').strip() in self.types_to_hide_title
+
+    def should_show_title(self):
+        """Return True if this post's title should be displayed. Use in templates to manage posts without titles."""
+        return not self.should_hide_title()
+
 
 def get_metadata_from_file(source_path, post, config, lang, metadata_extractors_by):
     """Extract metadata from the file itself, by parsing contents."""
@@ -1048,8 +1201,8 @@ def get_meta(post, lang):
         # Only perform these checks for the default language
         if 'slug' not in meta:
             # If no slug is found in the metadata use the filename
-            meta['slug'] = slugify(unicode_str(os.path.splitext(
-                os.path.basename(post.source_path))[0]), post.default_lang)
+            meta['slug'] = slugify(os.path.splitext(
+                os.path.basename(post.source_path))[0], post.default_lang)
 
         if 'title' not in meta:
             # If no title is found, use the filename without extension
@@ -1058,7 +1211,8 @@ def get_meta(post, lang):
 
     # Set one-file status basing on default language only (Issue #3191)
     if is_two_file or lang is None:
-        post.is_two_file = is_two_file
+        # Direct access because setter is complicated
+        post._is_two_file = is_two_file
 
     return meta, used_extractor
 
@@ -1108,8 +1262,14 @@ def insert_hyphens(node, hyphenator):
         text = getattr(node, attr)
         if not text:
             continue
-        new_data = ' '.join([hyphenator.inserted(w, hyphen='\u00AD')
-                             for w in text.split(' ')])
+
+        lines = text.splitlines()
+        new_data = "\n".join(
+            [
+                " ".join([hyphenator.inserted(w, hyphen="\u00AD") for w in line.split(" ")])
+                for line in lines
+            ]
+        )
         # Spaces are trimmed, we have to add them manually back
         if text[0].isspace():
             new_data = ' ' + new_data
