@@ -53,12 +53,14 @@ from zipfile import ZipFile as zipf
 import babel.dates
 import dateutil.parser
 import dateutil.tz
+import pygments.formatters
+import pygments.formatters._mapping
 import PyRSS2Gen as rss
 from blinker import signal
 from doit import tools
 from doit.cmdparse import CmdParse
 from pkg_resources import resource_filename
-from pygments.formatters import HtmlFormatter
+from nikola.packages.pygments_better_html import BetterHtmlFormatter
 from unidecode import unidecode
 
 # Renames
@@ -86,8 +88,8 @@ __all__ = ('CustomEncoder', 'get_theme_path', 'get_theme_path_real',
            'get_theme_chain', 'load_messages', 'copy_tree', 'copy_file',
            'slugify', 'unslugify', 'to_datetime', 'apply_filters',
            'config_changed', 'get_crumbs', 'get_tzname', 'get_asset_path',
-           '_reload', 'unicode_str', 'bytes_str', 'unichr', 'Functionary',
-           'TranslatableSetting', 'TemplateHookRegistry', 'LocaleBorg',
+           '_reload', 'Functionary', 'TranslatableSetting',
+           'TemplateHookRegistry', 'LocaleBorg',
            'sys_encode', 'sys_decode', 'makedirs', 'get_parent_theme_name',
            'demote_headers', 'get_translation_candidate', 'write_metadata',
            'ask', 'ask_yesno', 'options2docstring', 'os_path_split',
@@ -105,6 +107,7 @@ __all__ = ('CustomEncoder', 'get_theme_path', 'get_theme_path_real',
 # It's defined in nikola.nikola.Nikola (the site object).
 
 # Aliases, previously for Python 2/3 compatibility.
+# TODO remove in v9
 bytes_str = bytes
 unicode_str = str
 unichr = chr
@@ -168,14 +171,14 @@ ENCODING = sys.getfilesystemencoding() or sys.stdin.encoding
 
 def sys_encode(thing):
     """Return bytes encoded in the system's encoding."""
-    if isinstance(thing, unicode_str):
+    if isinstance(thing, str):
         return thing.encode(ENCODING)
     return thing
 
 
 def sys_decode(thing):
     """Return Unicode."""
-    if isinstance(thing, bytes_str):
+    if isinstance(thing, bytes):
         return thing.decode(ENCODING)
     return thing
 
@@ -203,7 +206,7 @@ class Functionary(defaultdict):
 
     def __init__(self, default, default_lang):
         """Initialize a functionary."""
-        super(Functionary, self).__init__(default)
+        super().__init__(default)
         self.default_lang = default_lang
 
     def __call__(self, key, lang=None):
@@ -240,7 +243,7 @@ class TranslatableSetting(object):
     def __getattribute__(self, attr):
         """Return attributes, falling back to string attributes."""
         try:
-            return super(TranslatableSetting, self).__getattribute__(attr)
+            return super().__getattribute__(attr)
         except AttributeError:
             return self().__getattribute__(attr)
 
@@ -485,7 +488,7 @@ class CustomEncoder(json.JSONEncoder):
     def default(self, obj):
         """Create default encoding handler."""
         try:
-            return super(CustomEncoder, self).default(obj)
+            return super().default(obj)
         except TypeError:
             if isinstance(obj, (set, frozenset)):
                 return self.encode(sorted(list(obj)))
@@ -501,7 +504,7 @@ class config_changed(tools.config_changed):
 
     def __init__(self, config, identifier=None):
         """Initialize config_changed."""
-        super(config_changed, self).__init__(config)
+        super().__init__(config)
         self.identifier = '_config_changed'
         if identifier is not None:
             self.identifier += ':' + identifier
@@ -809,12 +812,12 @@ def slugify(value, lang=None, force=False):
     >>> print(slugify('foo bar', lang='en'))
     foo-bar
     """
-    if not isinstance(value, unicode_str):
+    if not isinstance(value, str):
         raise ValueError("Not a unicode object: {0}".format(value))
     if USE_SLUGIFY or force:
         # This is the standard state of slugify, which actually does some work.
         # It is the preferred style, especially for Western languages.
-        value = unicode_str(unidecode(value))
+        value = str(unidecode(value))
         value = _slugify_strip_re.sub('', value).strip().lower()
         return _slugify_hyphenate_re.sub('-', value)
     else:
@@ -944,7 +947,7 @@ def apply_filters(task, filters, skip_ext=None):
             if isinstance(key, (tuple, list)):
                 if ext in key:
                     return value
-            elif isinstance(key, (bytes_str, unicode_str)):
+            elif isinstance(key, (bytes, str)):
                 if ext == key:
                     return value
             else:
@@ -1078,7 +1081,7 @@ class LocaleBorgUninitializedException(Exception):
 
     def __init__(self):
         """Initialize exception."""
-        super(LocaleBorgUninitializedException, self).__init__("Attempt to use LocaleBorg before initialization")
+        super().__init__("Attempt to use LocaleBorg before initialization")
 
 
 # Customized versions of babel.dates functions that don't do weird stuff with
@@ -1614,17 +1617,27 @@ def options2docstring(name, options):
     return '\n'.join(result)
 
 
-class NikolaPygmentsHTML(HtmlFormatter):
+class NikolaPygmentsHTML(BetterHtmlFormatter):
     """A Nikola-specific modification of Pygments' HtmlFormatter."""
 
-    def __init__(self, anchor_ref, classes=None, linenos='table', linenostart=1):
+    def __init__(self, anchor_ref=None, classes=None, **kwargs):
         """Initialize formatter."""
         if classes is None:
             classes = ['code', 'literal-block']
+        if anchor_ref:
+            kwargs['lineanchors'] = slugify(
+                anchor_ref, lang=LocaleBorg().current_lang, force=True)
         self.nclasses = classes
-        super(NikolaPygmentsHTML, self).__init__(
-            cssclass='code', linenos=linenos, linenostart=linenostart, nowrap=False,
-            lineanchors=slugify(anchor_ref, lang=LocaleBorg().current_lang, force=True), anchorlinenos=True)
+        kwargs['cssclass'] = 'code'
+        if not kwargs.get('linenos'):
+            # Default to no line numbers (Issue #3426)
+            kwargs['linenos'] = False
+        if kwargs.get('linenos') not in {'table', 'inline', 'ol', False}:
+            # Map invalid values to table
+            kwargs['linenos'] = 'table'
+        kwargs['anchorlinenos'] = kwargs['linenos'] == 'table'
+        kwargs['nowrap'] = False
+        super().__init__(**kwargs)
 
     def wrap(self, source, outfile):
         """Wrap the ``source``, which is a generator yielding individual lines, in custom generators."""
@@ -1642,6 +1655,10 @@ class NikolaPygmentsHTML(HtmlFormatter):
         yield 0, '</pre>'
 
 
+# For consistency, override the default formatter.
+pygments.formatters._formatter_cache['HTML'] = NikolaPygmentsHTML
+
+
 def get_displayed_page_number(i, num_pages, site):
     """Get page number to be displayed for entry `i`."""
     if not i:
@@ -1667,7 +1684,7 @@ def adjust_name_for_index_path_list(path_list, i, displayed_i, lang, site, force
             path_list.append(index_file)
         if site.config["PRETTY_URLS"] and site.config["INDEXES_PRETTY_PAGE_URL"](lang) and path_list[-1] == index_file:
             path_schema = site.config["INDEXES_PRETTY_PAGE_URL"](lang)
-            if isinstance(path_schema, (bytes_str, unicode_str)):
+            if isinstance(path_schema, (bytes, str)):
                 path_schema = [path_schema]
         else:
             path_schema = None
@@ -1858,7 +1875,7 @@ def smartjoin(join_char: str, string_or_iterable) -> str:
     >>> smartjoin(' to ', ['count', 42])
     'count to 42'
     """
-    if isinstance(string_or_iterable, (unicode_str, bytes_str)):
+    if isinstance(string_or_iterable, (str, bytes)):
         return string_or_iterable
     elif isinstance(string_or_iterable, Iterable):
         return join_char.join([str(e) for e in string_or_iterable])
@@ -1921,7 +1938,7 @@ def rss_writer(rss_obj, output_path):
     makedirs(dst_dir)
     with io.open(output_path, "w+", encoding="utf-8") as rss_file:
         data = rss_obj.to_xml(encoding='utf-8')
-        if isinstance(data, bytes_str):
+        if isinstance(data, bytes):
             data = data.decode('utf-8')
         rss_file.write(data)
 
